/*********************************************************************
* 
*
* Instructions for Running:
*   1. Select the digital lines on the DAQ device to be written.
*   2. Select a value to write.
*   Note: The array is sized for 8 lines, if using a different
*     amount of lines, change the number of elements in the
*     array to equal the number of lines chosen.
*
* Steps:
*   1. Create a task.
*   2. Create a Digital Output channel. Use one channel for all
*        lines.
*   3. Call the Start function to start the task.
*   4. Write the digital Boolean array data. This write function
*        writes a single sample of digital data on demand, so no
*        timeout is necessary.
*   5. Call the Clear Task function to clear the Task.
*   6. Display an error if any.
*
*
*  The following are the possible values for variable domecommand
*
*    define counterclockwise    0
*    define clockwise           1
*    define stop                2
*    define exit program        3
*
*  Added to this version-0.0.1
*  While loop that returns the program to the scanf function to await another
*    command so that the next input is recognized. 
*
*  Added value of 3 to exit the while loop to enable user to exit the program
*
*  If the first command of the program is not 1,2,or 3 or 
*    in other words if the first command is not to pass a set of digital 
*    values to the card, daqmx throws an error about unsupported digital 
*    values.  This does not stop the program however, and it 
*    loops back to accept new input.  This can be avoided by commenting 
*    out lines 109 and 110 but you lose daqmx error *reporting.  
*    This should not impact the function of this program.
*
*********************************************************************/

#include <stdio.h>
#include <NIDAQmx.h>

#define DAQmxErrChk(functionCall) if( DAQmxFailed(error=(functionCall)) ) goto Error; else

int main(void)
{
  int         domecommand;
  int32       error=0;
  TaskHandle  taskHandle=0;
  uInt8       data[2];
  char        errBuff[2048]={'\0'};
  int	      exitflag ,a,b;

  exitflag = 0; 

  printf ("Please enter a command\n");
  printf ("0=Rotate Counterclockwise\n");
  printf ("1=Rotate Clockwise\n");
  printf ("2=Stop Rotation\n");
  printf ("3=Exit the Dome Rotation Program\n");

  while ( !exitflag )
  {
    scanf( "%d", &domecommand );

    if (domecommand==0) 
    {
      data[0]= 0;
      data[1]= 1;
    }
    else if (domecommand==1)
    {
      data[0]= 1;
      data[1]= 0;
    }
    else if (domecommand==2) 
    {
      data[0]= 0;
      data[1]= 0;
    }
    else if (domecommand==3)
    {	
      exitflag = 1; 	
    }
    else 
    { 
      printf ("That is not a valid input.  Input 0,1,2 or 3.\n");
    }

    /*********************************************/
    // DAQmx Configure Code
    /*********************************************/
    
    /* This is where the device, line, and port are determined. */
    /* Port and lines depend on other cards installed and wiring. */
  
    DAQmxErrChk (DAQmxCreateTask("",&taskHandle));
    DAQmxErrChk (DAQmxCreateDOChan(taskHandle,"Dev1/port2/line0:1","",DAQmx_Val_ChanForAllLines));

    /*********************************************/
    // DAQmx Start Code
    /*********************************************/
    
    DAQmxErrChk (DAQmxStartTask(taskHandle));

    /*********************************************/
    // DAQmx Write Code
    /*********************************************/

    DAQmxErrChk (DAQmxWriteDigitalLines(taskHandle,1,1,10.0,DAQmx_Val_GroupByChannel,data,NULL,NULL));

    Error:
      if( DAQmxFailed(error) )
        DAQmxGetExtendedErrorInfo(errBuff,2048);
    
    if( taskHandle!=0 ) 
    {
      /*********************************************/
      // DAQmx Stop Code
      /*********************************************/
      
      DAQmxStopTask(taskHandle);
      DAQmxClearTask(taskHandle);
    }
    if( DAQmxFailed(error) )
      printf("DAQmx Error: %s\n",errBuff);
  }
  printf("Exiting\n");
  getchar();
  return 0;
}
